==> qtjambi-networkauth-debuginfo-macos-5.15.20.jar: sources/QtJambiNetworkAuth/QAbstractOAuth2_shell.h <==
#ifndef QABSTRACTOAUTH2_SHELL_H
#define QABSTRACTOAUTH2_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetworkAuth/qabstractoauth2.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttpmultipart.h>
#endif //QT_CONFIG(http)
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QAbstractOAuth2_shell : public QAbstractOAuth2, public QtJambiShellInterface
{
public:
    QAbstractOAuth2_shell(QNetworkAccessManager* manager0, QObject* parent1 = nullptr);
    QAbstractOAuth2_shell(QObject* parent0 = nullptr);
    ~QAbstractOAuth2_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QUrl createAuthenticatedUrl(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* post(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* put(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* put(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractOAuth2_access : public QAbstractOAuth2
{
    void __qt_setResponseType_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring responseType0);
    jobject __qt_createAuthenticatedUrl_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_deleteResource_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_get_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_head_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_post_cref_QUrl_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID data1);
    jobject __qt_post_cref_QUrl_QHttpMultiPart_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID multiPart1);
    jobject __qt_post_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_put_cref_QUrl_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID data1);
    jobject __qt_put_cref_QUrl_QHttpMultiPart_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID multiPart1);
    jobject __qt_put_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QABSTRACTOAUTH2_SHELL_H

==> qtjambi-networkauth-debuginfo-macos-6.5.3.jar: sources/QtJambiNetworkAuth/QAbstractOAuth2_shell.h <==
#ifndef QABSTRACTOAUTH2_SHELL_H
#define QABSTRACTOAUTH2_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtNetworkAuth/qabstractoauth2.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QMultiMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <qtnetwork-config.h>
#if QT_CONFIG(http)
#include <QtNetwork/qhttpmultipart.h>
#endif //QT_CONFIG(http)
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetworkAuth/qabstractoauth.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QAbstractOAuth2_shell : public QAbstractOAuth2, public QtJambiShellInterface
{
public:
    QAbstractOAuth2_shell(QNetworkAccessManager* manager0, QObject* parent1 = nullptr);
    QAbstractOAuth2_shell(QObject* parent0 = nullptr);
    ~QAbstractOAuth2_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QUrl createAuthenticatedUrl(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* post(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void prepareRequest(QNetworkRequest* request0, const QByteArray& verb1, const QByteArray& body2) override;
    QNetworkReply* put(const QUrl& url0, QHttpMultiPart* multiPart1) override;
    QNetworkReply* put(const QUrl& url0, const QByteArray& data1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMultiMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractOAuth2_access : public QAbstractOAuth2
{
    void __qt_setResponseType_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring responseType0);
    jobject __qt_createAuthenticatedUrl_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_deleteResource_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_get_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_head_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_post_cref_QUrl_QHttpMultiPart_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID multiPart1);
    jobject __qt_post_cref_QUrl_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID data1);
    jobject __qt_post_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_prepareRequest_QNetworkRequest_ptr_cref_QByteArray_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, QtJambiNativeID verb1, QtJambiNativeID body2);
    jobject __qt_put_cref_QUrl_QHttpMultiPart_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID multiPart1);
    jobject __qt_put_cref_QUrl_cref_QByteArray(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, QtJambiNativeID data1);
    jobject __qt_put_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QABSTRACTOAUTH2_SHELL_H
